# Postblog

The kickerly fast site management

Use is easier than any blog ever:
```
pip install postblog
postblog init
postblog open browser
```

After that just upload the site folder to a hosting or github pages

![1](_readme_files/1.png?raw=true)

![2](_readme_files/2.png?raw=true)

![3](_readme_files/3.png?raw=true)

![4](_readme_files/4.png?raw=true)
